CommonRegex class

Constructors

CommonRegex()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

emailValidator → RegExp
Matches email addresses
final
ninValidator → RegExp
Matches national insurance numbers in the UK
final
numberValidator → RegExp
Matches phone numbers addresses
final
postCodeValidator → RegExp
Matches UK post codes
final