ValidationError class

Constructors

ValidationError({String key = '', String message = '', String code = ''})
ValidationError.fromJson(String source)
factory
ValidationError.fromMap(Map<String, dynamic> map)
factory

Properties

code ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
key ↔ String
getter/setter pair
message ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited